summaryrefslogtreecommitdiffstats
path: root/kjs/ustring.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-03 04:12:51 +0000
commit560378aaca1784ba19806a0414a32b20c744de39 (patch)
treece0dfd7c3febf2a1adc7603d1019a8be2083c415 /kjs/ustring.cpp
parentd4d5af1cdbd3cc65d095e0afc5b1f4260091cf5d (diff)
downloadtdelibs-560378aaca1784ba19806a0414a32b20c744de39.tar.gz
tdelibs-560378aaca1784ba19806a0414a32b20c744de39.zip
Automated conversion for enhanced compatibility with TQt for Qt4 3.4.0 TP1
NOTE: This will not compile with Qt4 (yet), however it does compile with Qt3 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1211081 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kjs/ustring.cpp')
-rw-r--r--kjs/ustring.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/kjs/ustring.cpp b/kjs/ustring.cpp
index 36f201863..92644d009 100644
--- a/kjs/ustring.cpp
+++ b/kjs/ustring.cpp
@@ -134,7 +134,7 @@ static int statBufferSize = 0;
UChar UChar::toLower() const
{
// ### properly support unicode tolower
if (uc >= 256)
return *this;
@@ -746,7 +746,7 @@ unsigned int UString::toStrictUInt32(bool *ok) const
if (len == 0)
return 0;
const UChar *p = rep->dat;
- unsigned short c = p->unicode();
+ unsigned short c = p->tqunicode();
// If the first digit is 0, only 0 itself is OK.
if (c == '0') {
@@ -782,7 +782,7 @@ unsigned int UString::toStrictUInt32(bool *ok) const
}
// Get next character.
- c = (++p)->unicode();
+ c = (++p)->tqunicode();
}
}
@@ -796,7 +796,7 @@ unsigned UString::toArrayIndex(bool *ok) const
return i;
}
-int UString::find(const UString &f, int pos) const
+int UString::tqfind(const UString &f, int pos) const
{
int sz = size();
int fsz = f.size();
@@ -818,7 +818,7 @@ int UString::find(const UString &f, int pos) const
return -1;
}
-int UString::find(UChar ch, int pos) const
+int UString::tqfind(UChar ch, int pos) const
{
if (pos < 0)
pos = 0;
@@ -830,7 +830,7 @@ int UString::find(UChar ch, int pos) const
return -1;
}
-int UString::rfind(const UString &f, int pos) const
+int UString::rtqfind(const UString &f, int pos) const
{
int sz = size();
int fsz = f.size();
@@ -852,7 +852,7 @@ int UString::rfind(const UString &f, int pos) const
return -1;
}
-int UString::rfind(UChar ch, int pos) const
+int UString::rtqfind(UChar ch, int pos) const
{
if (isEmpty())
return -1;
@@ -134,7 +134,7 @@ static int statBufferSize = 0;
UChar UChar::toLower() const
{
- // ### properly support unicode tolower
+ // ### properly support tqunicode tolower
if (uc >= 256)
return *this;